# Changelog

## 1.0.0 (21/06/2021)

- Binance data provider added for fetching historical data for cryptocurrencies
- Interactive OHLCV candlestick charts in Jupyter notebook
- Backtesting engine added - Simulates a trading strategy's performance on historical data using a local paper trading account
- Added a huge library of technical indicators to use in your trading strategies. (The indicators use TA-lib under the hood to ensure rock-solid performance)
